@@ -202,6 +202,11 @@ fn main() {
             src_dir: "vendor/tree-sitter-hack-src",
             extra_files: vec!["scanner.cc"],
         },
+        TreeSitterParser {
+            name: "tree-sitter-hare",
+            src_dir: "vendor/tree-sitter-hare-src",
+            extra_files: vec![],
+        },
         TreeSitterParser {
             name: "tree-sitter-haskell",
             src_dir: "vendor/tree-sitter-haskell-src",
@@ -273,20 +278,30 @@ fn main() {
             extra_files: vec!["scanner.cc"],
         },
         TreeSitterParser {
-            name: "tree-sitter-php",
-            src_dir: "vendor/tree-sitter-php-src",
-            extra_files: vec!["scanner.cc"],
+            name: "tree-sitter-pascal",
+            src_dir: "vendor/tree-sitter-pascal-src",
+            extra_files: vec![],
         },
         TreeSitterParser {
             name: "tree-sitter-perl",
             src_dir: "vendor/tree-sitter-perl-src",
             extra_files: vec!["scanner.cc"],
         },
+        TreeSitterParser {
+            name: "tree-sitter-php",
+            src_dir: "vendor/tree-sitter-php-src",
+            extra_files: vec!["scanner.cc"],
+        },
         TreeSitterParser {
             name: "tree-sitter-python",
             src_dir: "vendor/tree-sitter-python-src",
             extra_files: vec!["scanner.cc"],
         },
+        TreeSitterParser {
+            name: "tree-sitter-qmljs",
+            src_dir: "vendor/tree-sitter-qmljs-src",
+            extra_files: vec!["scanner.c"],
+        },
         TreeSitterParser {
             name: "tree-sitter-ruby",
             src_dir: "vendor/tree-sitter-ruby-src",
