@@ -3,7 +3,7 @@
 /// The maximum number of lines that may occur between changed lines in a hunk.
 ///
 /// If we exceed this, the lines are stored in separate hunks.
-const MAX_DISTANCE: usize = 4;
+const MAX_DISTANCE: u32 = 4;
 
 use std::collections::HashSet;
 
@@ -595,10 +595,10 @@ fn either_side_equal(
     false
 }
 
-pub fn matched_lines_for_hunk(
+pub fn matched_lines_indexes_for_hunk(
     matched_lines: &[(Option<LineNumber>, Option<LineNumber>)],
     hunk: &Hunk,
-) -> Vec<(Option<LineNumber>, Option<LineNumber>)> {
+) -> (usize, usize) {
     let mut hunk_lhs_novel = hunk.novel_lhs.iter().copied().collect::<Vec<_>>();
     hunk_lhs_novel.sort();
 
@@ -645,7 +645,7 @@ pub fn matched_lines_for_hunk(
         end_i = matched_lines.len();
     }
 
-    matched_lines[start_i..end_i].to_vec()
+    (start_i, end_i)
 }
 
 #[cfg(test)]
@@ -758,6 +758,14 @@ mod tests {
         assert_eq!(hunks[0].lines, vec![(Some(0.into()), Some(0.into()))]);
     }
 
+    fn matched_lines_for_hunk<'a>(
+        matched_lines: &'a [(Option<LineNumber>, Option<LineNumber>)],
+        hunk: &Hunk,
+    ) -> &'a [(Option<LineNumber>, Option<LineNumber>)] {
+        let (start_i, end_i) = matched_lines_indexes_for_hunk(matched_lines, hunk);
+        &matched_lines[start_i..end_i]
+    }
+
     #[test]
     fn test_matched_lines_for_hunk() {
         let matched_lines = &[
