@@ -4,7 +4,10 @@ use crate::{
     constants::Side,
     lines::{byte_len, split_on_newlines, LineNumber},
     options::DisplayOptions,
-    parse::syntax::{AtomKind, MatchKind, MatchedPos, TokenKind},
+    parse::{
+        guess_language::Language,
+        syntax::{AtomKind, MatchKind, MatchedPos, TokenKind},
+    },
     positions::SingleLineSpan,
 };
 use owo_colors::{OwoColorize, Style};
@@ -24,33 +27,27 @@ impl BackgroundColor {
     }
 }
 
-/// Slice `s` from `start` inclusive to `end` exclusive by width.
-fn substring_by_width(s: &str, start: usize, end: usize) -> &str {
-    if start == end {
-        return &s[0..0];
+/// Find the largest byte offset in `s` that gives the longest
+/// starting substring whose display width does not exceed `width`.
+///
+/// Note that the resulting substring may have a display width less
+/// than `width`, if the string contains full-width or emoji
+/// characters which have a display width greater than 1.
+fn byte_offset_for_width(s: &str, width: usize) -> usize {
+    let mut current_offset = 0;
+    let mut current_width = 0;
+
+    for (offset, ch) in s.char_indices() {
+        current_offset = offset;
+        let char_width = ch.width().unwrap_or(0);
+        current_width += char_width;
+
+        if current_width > width {
+            break;
+        }
     }
 
-    assert!(end > start);
-
-    let mut idx_width_iter = s
-        .char_indices()
-        .scan(0, |w, (idx, ch)| {
-            let before = *w;
-            *w += ch.width().unwrap_or(0);
-            Some((idx, before, *w))
-        })
-        .skip_while(|(_, before, _)| *before < start);
-    let byte_start = idx_width_iter
-        .next()
-        .expect("Expected a width index inside `s`.")
-        .0;
-    match idx_width_iter
-        .skip_while(|(_, _, after)| *after <= end)
-        .next()
-    {
-        Some(byte_end) => &s[byte_start..byte_end.0],
-        None => &s[byte_start..],
-    }
+    current_offset
 }
 
 fn substring_by_byte(s: &str, start: usize, end: usize) -> &str {
@@ -70,16 +67,18 @@ fn split_string_by_width(s: &str, max_width: usize, pad: bool) -> Vec<(&str, usi
     let mut s = s;
 
     while s.width() > max_width {
-        let l = substring_by_width(s, 0, max_width);
-        let used = l.width();
-        let padding = if pad && used < max_width {
+        let offset = byte_offset_for_width(s, max_width);
+
+        let part = substring_by_byte(s, 0, offset);
+        s = substring_by_byte(s, offset, s.len());
+
+        let padding = if pad && part.width() < max_width {
             // a fullwidth char is followed
             1
         } else {
             0
         };
-        res.push((l, padding));
-        s = substring_by_width(s, used, s.width());
+        res.push((part, padding));
     }
 
     if res.is_empty() || !s.is_empty() {
@@ -104,6 +103,8 @@ pub fn split_and_apply(
     styles: &[(SingleLineSpan, Style)],
     side: Side,
 ) -> Vec<String> {
+    assert!(max_len > 0);
+
     if styles.is_empty() && !line.trim().is_empty() {
         // Missing styles is a bug, so highlight in purple to make this obvious.
         return split_string_by_width(line, max_len, matches!(side, Side::Left))
@@ -121,15 +122,15 @@ pub fn split_and_apply(
     let mut styled_parts = vec![];
     let mut part_start = 0;
 
-    for (part, pad) in split_string_by_width(line, max_len, matches!(side, Side::Left)) {
-        let mut res = String::with_capacity(part.len() + pad);
+    for (line_part, pad) in split_string_by_width(line, max_len, matches!(side, Side::Left)) {
+        let mut res = String::with_capacity(line_part.len() + pad);
         let mut prev_style_end = 0;
         for (span, style) in styles {
             let start_col = span.start_col as usize;
             let end_col = span.end_col as usize;
 
-            // The remaining spans are beyond the end of this part.
-            if start_col >= part_start + byte_len(&part) {
+            // The remaining spans are beyond the end of this line_part.
+            if start_col >= part_start + byte_len(&line_part) {
                 break;
             }
 
@@ -138,7 +139,7 @@ pub fn split_and_apply(
                 // Then append that text without styling.
                 let unstyled_start = max(prev_style_end, part_start);
                 res.push_str(substring_by_byte(
-                    part,
+                    line_part,
                     unstyled_start - part_start,
                     start_col - part_start,
                 ));
@@ -147,9 +148,9 @@ pub fn split_and_apply(
             // Apply style to the substring in this span.
             if end_col > part_start {
                 let span_s = substring_by_byte(
-                    part,
+                    line_part,
                     max(0, span.start_col as isize - part_start as isize) as usize,
-                    min(byte_len(part), end_col - part_start),
+                    min(byte_len(line_part), end_col - part_start),
                 );
                 res.push_str(&span_s.style(*style).to_string());
             }
@@ -157,20 +158,21 @@ pub fn split_and_apply(
         }
 
         // Ensure that prev_style_end is at least at the start of this
-        // part.
+        // line_part.
         if prev_style_end < part_start {
             prev_style_end = part_start;
         }
 
         // Unstyled text after the last span.
-        if prev_style_end < part_start + byte_len(part) {
-            let span_s = substring_by_byte(part, prev_style_end - part_start, byte_len(part));
+        if prev_style_end < part_start + byte_len(line_part) {
+            let span_s =
+                substring_by_byte(line_part, prev_style_end - part_start, byte_len(line_part));
             res.push_str(span_s);
         }
         res.push_str(&" ".repeat(pad));
 
         styled_parts.push(res);
-        part_start += byte_len(part);
+        part_start += byte_len(line_part);
     }
 
     styled_parts
@@ -268,6 +270,7 @@ pub fn color_positions(
     is_lhs: bool,
     background: BackgroundColor,
     syntax_highlight: bool,
+    language: Option<Language>,
     positions: &[MatchedPos],
 ) -> Vec<(SingleLineSpan, Style)> {
     let mut styles = vec![];
@@ -319,6 +322,13 @@ pub fn color_positions(
             }
             MatchKind::NovelWord { highlight } => {
                 style = novel_style(style, is_lhs, background).bold();
+
+                // Underline novel words inside comments in code, but
+                // don't apply it to every single line in plaintext.
+                if language.is_some() {
+                    style = style.underline();
+                }
+
                 if syntax_highlight && matches!(highlight, TokenKind::Atom(AtomKind::Comment)) {
                     style = style.italic();
                 }
@@ -339,10 +349,11 @@ pub fn apply_colors(
     s: &str,
     is_lhs: bool,
     syntax_highlight: bool,
+    language: Option<Language>,
     background: BackgroundColor,
     positions: &[MatchedPos],
 ) -> Vec<String> {
-    let styles = color_positions(is_lhs, background, syntax_highlight, positions);
+    let styles = color_positions(is_lhs, background, syntax_highlight, language, positions);
     let lines = split_on_newlines(s);
     style_lines(&lines, &styles)
 }
@@ -433,6 +444,14 @@ mod tests {
         );
     }
 
+    #[test]
+    fn test_combining_char() {
+        assert_eq!(
+            split_string_by_width("aabbcc\u{300}x", 6, false),
+            vec![("aabbcc\u{300}", 0), ("x", 0)],
+        );
+    }
+
     #[test]
     fn split_string_cjk() {
         assert_eq!(
