@@ -115,6 +115,10 @@ pub fn guess_content(bytes: &[u8]) -> ProbableFileKind {
     match mime {
         // Treat pdf as binary.
         "application/pdf" => return ProbableFileKind::Binary,
+        // application/* is a mix of stuff, application/json is fine
+        // but application/zip is binary that often looks text-ish to
+        // our heuristics.
+        "application/zip" => return ProbableFileKind::Binary,
         // Treat all image content as binary.
         v if v.starts_with("image/") => return ProbableFileKind::Binary,
         // Treat all audio content as binary.
@@ -135,7 +139,7 @@ pub fn guess_content(bytes: &[u8]) -> ProbableFileKind {
         .take(1000)
         .filter(|c| *c == std::char::REPLACEMENT_CHARACTER || *c == '\0')
         .count();
-    if num_utf8_invalid <= 20 {
+    if num_utf8_invalid <= 10 {
         return ProbableFileKind::Text(utf8_string);
     }
 
@@ -145,7 +149,7 @@ pub fn guess_content(bytes: &[u8]) -> ProbableFileKind {
         .take(1000)
         .filter(|c| *c == std::char::REPLACEMENT_CHARACTER || *c == '\0')
         .count();
-    if num_utf16_invalid <= 20 {
+    if num_utf16_invalid <= 5 {
         return ProbableFileKind::Text(utf16_string);
     }
 
