@@ -34,6 +34,7 @@ pub enum Language {
     Gleam,
     Go,
     Hack,
+    Hare,
     Haskell,
     Hcl,
     Html,
@@ -49,9 +50,11 @@ pub enum Language {
     Nix,
     OCaml,
     OCamlInterface,
-    Php,
+    Pascal,
     Perl,
+    Php,
     Python,
+    Qml,
     Ruby,
     Rust,
     Scala,
@@ -83,6 +86,7 @@ pub fn language_name(language: Language) -> &'static str {
         Gleam => "Gleam",
         Go => "Go",
         Hack => "Hack",
+        Hare => "Hare",
         Haskell => "Haskell",
         Hcl => "HCL",
         Html => "HTML",
@@ -98,9 +102,11 @@ pub fn language_name(language: Language) -> &'static str {
         Nix => "Nix",
         OCaml => "OCaml",
         OCamlInterface => "OCaml Interface",
-        Php => "PHP",
+        Pascal => "Pascal",
         Perl => "Perl",
+        Php => "PHP",
         Python => "Python",
+        Qml => "QML",
         Ruby => "Ruby",
         Rust => "Rust",
         Scala => "Scala",
@@ -145,6 +151,7 @@ pub const LANG_EXTENSIONS: &'static [(Language, &[&str])] = &[
     (Gleam, &["gleam"]),
     (Go, &["go"]),
     (Hack, &["hack", "hck", "hhi"]),
+    (Hare, &["ha"]),
     (Haskell, &["hs"]),
     (Hcl, &["hcl", "nomad", "tf", "tfvars", "workflow"]),
     (Html, &["html", "htm", "xhtml"]),
@@ -178,9 +185,11 @@ pub const LANG_EXTENSIONS: &'static [(Language, &[&str])] = &[
     (Nix, &["nix"]),
     (OCaml, &["ml"]),
     (OCamlInterface, &["mli"]),
-    (Php, &["php"]),
+    (Pascal, &["pas", "dfm", "dpr", "lpr", "pascal"]),
     (Perl, &["pm", "pl"]),
+    (Php, &["php"]),
     (Python, &["py", "py3", "pyi", "bzl"]),
+    (Qml, &["qml"]),
     (Ruby, &["rb", "builder", "spec", "rake"]),
     (Rust, &["rs"]),
     (Scala, &["scala", "sbt", "sc"]),
