@@ -55,6 +55,7 @@ extern "C" {
     fn tree_sitter_elvish() -> ts::Language;
     fn tree_sitter_gleam() -> ts::Language;
     fn tree_sitter_go() -> ts::Language;
+    fn tree_sitter_hare() -> ts::Language;
     fn tree_sitter_hack() -> ts::Language;
     fn tree_sitter_haskell() -> ts::Language;
     fn tree_sitter_hcl() -> ts::Language;
@@ -70,9 +71,11 @@ extern "C" {
     fn tree_sitter_nix() -> ts::Language;
     fn tree_sitter_ocaml() -> ts::Language;
     fn tree_sitter_ocaml_interface() -> ts::Language;
+    fn tree_sitter_pascal() -> ts::Language;
     fn tree_sitter_php() -> ts::Language;
     fn tree_sitter_perl() -> ts::Language;
     fn tree_sitter_python() -> ts::Language;
+    fn tree_sitter_qmljs() -> ts::Language;
     fn tree_sitter_ruby() -> ts::Language;
     fn tree_sitter_rust() -> ts::Language;
     fn tree_sitter_scala() -> ts::Language;
@@ -325,6 +328,21 @@ pub fn from_language(language: guess::Language) -> TreeSitterConfig {
                 .unwrap(),
             }
         }
+        Hare => {
+            let language = unsafe { tree_sitter_hare() };
+            TreeSitterConfig {
+                language,
+                atom_nodes: vec!["string_constant", "rune_constant"]
+                    .into_iter()
+                    .collect(),
+                delimiter_tokens: vec![("[", "]"), ("(", ")"), ("{", "}")],
+                highlight_query: ts::Query::new(
+                    language,
+                    include_str!("../../vendor/highlights/hare.scm"),
+                )
+                .unwrap(),
+            }
+        }
         Haskell => {
             let language = unsafe { tree_sitter_haskell() };
             TreeSitterConfig {
@@ -508,7 +526,7 @@ pub fn from_language(language: guess::Language) -> TreeSitterConfig {
             let language = unsafe { tree_sitter_make() };
             TreeSitterConfig {
                 language,
-                atom_nodes: vec![].into_iter().collect(),
+                atom_nodes: vec!["shell_text"].into_iter().collect(),
                 delimiter_tokens: vec![("(", ")")].into_iter().collect(),
                 highlight_query: ts::Query::new(
                     language,
@@ -558,15 +576,15 @@ pub fn from_language(language: guess::Language) -> TreeSitterConfig {
                 .unwrap(),
             }
         }
-        Php => {
-            let language = unsafe { tree_sitter_php() };
+        Pascal => {
+            let language = unsafe { tree_sitter_pascal() };
             TreeSitterConfig {
                 language,
-                atom_nodes: vec!["string", "encapsed_string"].into_iter().collect(),
-                delimiter_tokens: vec![("(", ")"), ("[", "]"), ("{", "}")],
+                atom_nodes: vec![].into_iter().collect(),
+                delimiter_tokens: vec![("(", ")"), ("[", "]")],
                 highlight_query: ts::Query::new(
                     language,
-                    include_str!("../../vendor/highlights/php.scm"),
+                    include_str!("../../vendor/highlights/pascal.scm"),
                 )
                 .unwrap(),
             }
@@ -595,6 +613,19 @@ pub fn from_language(language: guess::Language) -> TreeSitterConfig {
                 .unwrap(),
             }
         }
+        Php => {
+            let language = unsafe { tree_sitter_php() };
+            TreeSitterConfig {
+                language,
+                atom_nodes: vec!["string", "encapsed_string"].into_iter().collect(),
+                delimiter_tokens: vec![("(", ")"), ("[", "]"), ("{", "}")],
+                highlight_query: ts::Query::new(
+                    language,
+                    include_str!("../../vendor/highlights/php.scm"),
+                )
+                .unwrap(),
+            }
+        }
         Python => {
             let language = unsafe { tree_sitter_python() };
             TreeSitterConfig {
@@ -608,6 +639,25 @@ pub fn from_language(language: guess::Language) -> TreeSitterConfig {
                 .unwrap(),
             }
         }
+        Qml => {
+            let language = unsafe { tree_sitter_qmljs() };
+            TreeSitterConfig {
+                language,
+                atom_nodes: vec!["string", "template_string", "regex"]
+                    .into_iter()
+                    .collect(),
+                delimiter_tokens: vec![("{", "}"), ("(", ")"), ("[", "]"), ("<", ">")],
+                highlight_query: ts::Query::new(
+                    language,
+                    concat!(
+                        include_str!("../../vendor/highlights/javascript.scm"),
+                        include_str!("../../vendor/highlights/typescript.scm"),
+                        include_str!("../../vendor/highlights/qmljs.scm"),
+                    ),
+                )
+                .unwrap(),
+            }
+        }
         Ruby => {
             let language = unsafe { tree_sitter_ruby() };
             TreeSitterConfig {
@@ -1188,7 +1238,9 @@ fn atom_from_cursor<'a>(
         content = content.trim();
     }
 
-    // Most languages use "comment", but Perl uses "comments".
+    // 'extra' nodes in tree-sitter are comments. Most parsers use
+    // 'comment' as their comment node name, but if they don't we can
+    // still detect comments by looking at their syntax highlighting.
     let highlight = if node.is_extra()
         || node.kind() == "comment"
         || highlights.comment_ids.contains(&node.id())
